package ch.epfl.ppo.generators;

import ch.epfl.ppo.Animation;
import ch.epfl.ppo.Image;

public final class DissolveMask implements Animation<Double> {
    private final double t1, t2;

    public DissolveMask(double t1, double t2) {
        if (! (0 <= t1 && t1 < t2))
            throw new IllegalArgumentException("invalid time interval: [" + t1 + ";" + t2 + "]");
        this.t1 = t1;
        this.t2 = t2;
    }

    @Override
    public Image<Double> imageAt(double time) {
        double clampedTime = Math.max(t1, Math.min(time, t2));
        return new ConstantImage<>((clampedTime - t1) / (t2 - t1));
    }
}
