package ch.epfl.ppo.generators;

import ch.epfl.ppo.ColorRGB;
import ch.epfl.ppo.Image;

public final class LinearHorizontalGradientGenerator implements Image<ColorRGB> {
    private final ColorRGB leftColor, rightColor;
    private final double leftX, rightX;

    public LinearHorizontalGradientGenerator(ColorRGB leftColor, double leftX, ColorRGB rightColor, double rightX) {
        if (! (leftX < rightX))
            throw new IllegalArgumentException("invalid interval: [" + leftX + ";" + rightX + "]");
        this.leftColor = leftColor;
        this.leftX = leftX;
        this.rightColor = rightColor;
        this.rightX = rightX;
    }

    @Override
    public ColorRGB valueAt(double x, double y) {
        if (x <= leftX)
            return leftColor;
        else if (x >= rightX)
            return rightColor;
        else {
            double p = (x - leftX) / (rightX - leftX);
            return leftColor.mixWith(rightColor, p);
        }
    }
}
